{% extends 'generic/object_list.html' %}
{% load helpers %}

{% block title %}FreeIPA DNS Zones{% endblock %}

{% block controls %}
    <form method="post" action="{% url 'plugins:netbox_freeipa:freeipahost_sync' %}" class="d-inline">
        {% csrf_token %}
        <input type="hidden" name="sync_type" value="dns_zones">
        <button type="submit" class="btn btn-primary">
            <i class="mdi mdi-sync"></i> Sync DNS Zones
        </button>
    </form>
{% endblock %}
