{% extends 'generic/object_edit.html' %}
{% load helpers %}

{% block title %}
    {% if object.pk %}
        Editing DNS Zone {{ object }}
    {% else %}
        Add a new DNS Zone
    {% endif %}
{% endblock %}
