{% extends 'generic/object_edit.html' %}
{% load helpers %}

{% block title %}
    {% if object.pk %}
        Editing DNS Record {{ object }}
    {% else %}
        Add a new DNS Record
    {% endif %}
{% endblock %}
